@@ -17,9 +17,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Autoload.py,v 1.3 2000/02/10 09:40:13 fredgo Exp $
+# $Id: Autoload.py,v 1.3.2.1 2000/10/17 10:40:46 fredgo Exp $
 
-import os, string, re, gettext
+import os, string, re, gettext, sys
 
 _ = gettext.gettext
 
@@ -79,9 +79,13 @@ def preregister (group, name, module, regexp = None, info = None):
         gp = {}
         __loaders [group] = gp
 
-        
+    lc = string.lower (name)
+    # are we preregistering an existing key ?
+    if gp.has_key (lc):
+        return gp [lc]
+    
     lo = Loader (name, regexp, module, info)
-    gp [string.lower (name)] = lo
+    gp [lc] = lo
     
     return lo
 
