@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Base.py,v 1.11.2.2 2000/10/17 10:40:46 fredgo Exp $
+# $Id: Base.py,v 1.11.2.3 2001/06/25 14:24:52 fredgo Exp $
 
 from string import *
 import re, copy, os
@@ -281,14 +281,20 @@ class DataBase:
 
 	name = self.key.url [2]
 
-	# backup file
-	os.rename (name, name + '.bak')
-
-	tmpfile = open (name, 'w')
+        # create a temporary file for the new version
+        tmp = os.path.join (os.path.dirname (name),
+                            '.#' + os.path.basename (name))
+        
+        tmpfile = open (tmp, 'w')
 
         iterator = Selection.Selection (sort = sorting).iterator (self.iterator ())
-        
 	Open.bibwrite (iterator, out = tmpfile, how = self.id)
+        
 	tmpfile.close ()
+        
+	# if we succeeded, backup file
+	os.rename (name, name + '.bak')
+	# ...and bring new version online
+        os.rename (tmp, name)
         return
 
