@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Document.py,v 1.18.2.8 2000/09/25 08:16:34 fredgo Exp $
+# $Id: Document.py,v 1.18.2.10 2001/05/10 13:40:56 fredgo Exp $
 
 ''' This module defines a Document class '''
 
@@ -36,7 +36,7 @@ from Pyblio import version, Fields, Types
 
 import Pyblio.Style.Utils
 
-import gettext, os, string, copy, types, sys, traceback
+import gettext, os, string, copy, types, sys, traceback, stat
 
 _ = gettext.gettext
 
@@ -108,7 +108,7 @@ class Document (Connector.Publisher):
             UIINFO_ITEM_STOCK(_("Save"),  None, self.save_document,    STOCK_PIXMAP_SAVE),
             UIINFO_SEPARATOR,
             UIINFO_ITEM_STOCK(_("Find"),  None, self.find_entries,     STOCK_PIXMAP_SEARCH),
-            UIINFO_ITEM_STOCK(_("Cite"), None, self.lyx_cite,          STOCK_MENU_CONVERT),
+            UIINFO_ITEM_STOCK(_("Cite"),  None, self.lyx_cite,          STOCK_MENU_CONVERT),
             UIINFO_SEPARATOR,
             UIINFO_ITEM_STOCK(_("Close"), None, self.close_document,   STOCK_PIXMAP_CLOSE),
             ]
@@ -167,7 +167,9 @@ class Document (Connector.Publisher):
         self.lyx       = None
         self.changed   = 0
         self.directory = None
-        
+
+        self.modification_date = None
+
         self.redisplay_index ()
         return
 
@@ -395,12 +397,23 @@ class Document (Connector.Publisher):
         # eventually warn interested objects
         self.issue ('open-document', self)
         return
+
     
     def save_document (self, * arg):
         if self.data.key is None:
             self.save_document_as ()
             return
 
+        file = self.data.key.url [2]
+        
+        if self.modification_date:
+            mod_date = os.stat (file) [stat.ST_MTIME]
+            
+            if mod_date > self.modification_date:
+                if not Utils.Callback (_("The database has been externally modified.\nOverwrite changes ?"),
+                                       self.w).answer ():
+                    return
+        
         Utils.set_cursor (self.w, 'clock')
         try:
             try:
@@ -420,6 +433,9 @@ class Document (Connector.Publisher):
 
         Utils.set_cursor (self.w, 'normal')
 
+        # get the current modification date
+        self.modification_date = os.stat (file) [stat.ST_MTIME]
+        
         self.update_status (0)
         return
     
@@ -449,22 +465,20 @@ class Document (Connector.Publisher):
                        out = file, how = how)
         file.close ()
         
-        if self.data.key is None:
-            # we wrote an anonymous database. Lets reopen it !
-            try:
-                self.data = Open.bibopen (url, how = how)
+        try:
+            self.data = Open.bibopen (url, how = how)
                 
-            except (Exceptions.ParserError,
-                    Exceptions.FormatError,
-                    Exceptions.FileError), error:
+        except (Exceptions.ParserError,
+                Exceptions.FormatError,
+                Exceptions.FileError), error:
                     
-                Utils.set_cursor (self.w, 'normal')
-                Utils.error_dialog (_("Reopen error"), error,
-                                    parent = self.w)
-                return
+            Utils.set_cursor (self.w, 'normal')
+            Utils.error_dialog (_("Reopen error"), error,
+                                parent = self.w)
+            return
             
-            self.redisplay_index ()
-            self.issue ('open-document', self)
+        self.redisplay_index ()
+        self.issue ('open-document', self)
             
         Utils.set_cursor (self.w, 'normal')
 
