@@ -17,11 +17,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Pybliographic.py,v 1.13 2000/04/14 11:18:50 fredgo Exp $
+# $Id: Pybliographic.py,v 1.13.2.1 2000/11/13 09:35:25 fredgo Exp $
 
 ''' Main Module holding all the documents '''
 
-import gettext, copy
+import gettext, copy, os, stat
 
 _ = gettext.gettext
 
@@ -92,6 +92,12 @@ class Pybliographic:
         # warn all the documents
         for doc in self.documents:
             doc.update_history (self.opened)
+
+        # get the modification date...
+        if doc.data.key.url [0] == 'file':
+            file = doc.data.key.url [2]
+            doc.modification_date = os.stat (file) [stat.ST_MTIME]
+        
         return
 
     
