@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Utils.py,v 1.3.2.3 2000/10/17 10:40:46 fredgo Exp $
+# $Id: Utils.py,v 1.3.2.4 2001/06/25 14:25:24 fredgo Exp $
 
 from string import *
 
@@ -58,7 +58,7 @@ __entry = 0
 
 
 def generate_key (entry, table):
-    
+
     if   entry.has_key ('author'): aut = entry ['author']
     elif entry.has_key ('editor'): aut = entry ['editor']
     else:                          aut = ()
@@ -91,8 +91,8 @@ def generate_key (entry, table):
         if entry.has_key ('date'):
             year = entry ['date'].year
             
-            if year:
-                key = key + str (year) [2:]
+            if year: key = key + str (year) [2:]
+
 
     base = key
     key  = Key.Key (table, base)
@@ -106,9 +106,9 @@ def generate_key (entry, table):
             if suff > ord ('z'):
                 suff = ord ('a')
                 base = base + 'a'
-                
+
             key  = Key.Key (table, base + chr (suff))
-	            
+            
     return Key.Key (table, key)
 
 Autoload.register ('key', 'Default', generate_key)
