@@ -369,7 +369,7 @@ static const short yycheck[] = {     5,
     15,    14,    12,     0,     0,    40,    18
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "//usr/lib/bison.simple"
+#line 3 "/usr/lib/bison.simple"
 /* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
@@ -583,7 +583,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
 #endif
 #endif
 
-#line 217 "//usr/lib/bison.simple"
+#line 217 "/usr/lib/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -1221,7 +1221,7 @@ case 32:
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 543 "//usr/lib/bison.simple"
+#line 543 "/usr/lib/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
