@@ -18,19 +18,20 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: reverse.c,v 1.7 2000/04/14 11:17:42 fredgo Exp $
+ $Id: reverse.c,v 1.8.2.5 2001/06/25 16:04:02 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include <string.h>
+#include <regex.h>
+
 #ifdef HAVE_STDBOOL_H
 #include <stdbool.h>
 #else /* ! HAVE_STDBOOL_H */
 
-#include <string.h>
-
 /* stdbool.h for GNU.  */
 
 /* The type `bool' must promote to `int' or `unsigned int'.  The constants
@@ -82,18 +83,34 @@ text_to_struct (gchar * string) {
     
     bibtex_entry_destroy (entry, TRUE);
 
-/*      bibtex_source_destroy (source, TRUE); */
-
     return s;
 }
 
+
+static gboolean
+author_needs_quotes (gchar * string) {
+  static gboolean initialized = FALSE;
+  static regex_t and_re;
+  
+  if (! initialized) {
+    initialized = regcomp (& and_re, "[^[:alnum:]]and[^[:alnum:]]", REG_ICASE |
+			   REG_EXTENDED) == 0;
+    g_assert (initialized);
+  }
+
+  return
+    (strpbrk (string, ",") != NULL) || 
+    (regexec (& and_re, string, 0,NULL, 0)  == 0);
+}
+
+
 BibtexField * 
 bibtex_reverse_field (BibtexField * field,
 		      gboolean use_braces) {
 #ifdef USE_RECODE
     BibtexStruct * s;
     gchar * string, * tmp, c;
-    gboolean has_upper, is_upper;
+    gboolean has_upper, is_upper, has_space, is_command;
     gint start, stop, last, i;
     BibtexAuthor * author;
 
@@ -131,14 +148,14 @@ bibtex_reverse_field (BibtexField * field,
 
 	g_string_truncate (st, 0);
 
-	tmp = recode_string (request, field->text);
-
 	if (! use_braces) {
-	    if (strchr (tmp, '"')) {
+	    if (strchr (field->text, '"')) {
 	        use_braces = TRUE;
 	    }
 	}
 
+	tmp = recode_string (request, field->text);
+
 	if (use_braces) {
 	    g_string_append (st, "@preamble{{");
 	}
@@ -164,14 +181,14 @@ bibtex_reverse_field (BibtexField * field,
 
 	g_string_truncate (st, 0);
 	
-	tmp = recode_string (request, field->text);
-
 	if (! use_braces) {
-	    if (strchr (tmp, '"')) {
+	    if (strchr (field->text, '"')) {
 	        use_braces = TRUE;
 	    }
 	}
 
+	tmp = recode_string (request, field->text);
+
 	if (use_braces) {
 	    g_string_append (st, "@preamble{{");
 	}
@@ -179,19 +196,53 @@ bibtex_reverse_field (BibtexField * field,
 	    g_string_append (st, "@preamble{\"");
 	}
 
-	/* Put the upper cases or the first lower cases between {} */
+	/* Put the first lower case between {} */
 	string = tmp;
 	if (* tmp >= 'a' && * tmp <= 'z') {
 	    /* Put the beginning in lower cases */
 	    g_string_append_c (st, '{');
 	    g_string_append_c (st, * tmp);
 	    g_string_append_c (st, '}');
-	    tmp ++;
 	}
+	else {
+	    /* The first character is done */
+	    g_string_append_c (st, * tmp);
+	}
+	
+	tmp ++;
+
+	/* check for upper cases afterward */
+	is_upper   = false;
+	is_command = false;
 
-	is_upper = false;
 	while (* tmp) {
-	    if (* tmp >= 'A' && * tmp <= 'Z' && (tmp > string)) {
+	    /* start a latex command */
+	    if (* tmp == '\\') {
+
+		/* eventually closes the bracket */
+		if (is_upper) {
+		    is_upper = false;
+		    g_string_append_c (st, '}');
+		}
+
+		is_command = true;
+		g_string_append_c (st, * tmp);
+		tmp ++;
+
+		continue;
+	    }
+	    if (is_command) {
+		if (! ((* tmp >= 'a' && * tmp <= 'z') ||
+		       (* tmp >= 'A' && * tmp <= 'Z'))) {
+		    is_command = false;
+		}
+		g_string_append_c (st, * tmp);
+		tmp ++;
+
+		continue;
+	    }
+
+	    if (* tmp >= 'A' && * tmp <= 'Z') {
 		if (! is_upper) {
 		    g_string_append_c (st, '{');
 		    is_upper = true;
@@ -208,6 +259,8 @@ bibtex_reverse_field (BibtexField * field,
 	    }
 	    tmp ++;
 	}
+
+	/* eventually close the brackets */
 	if (is_upper) {
 	    g_string_append_c (st, '}');
 	    is_upper = false;
@@ -220,7 +273,7 @@ bibtex_reverse_field (BibtexField * field,
 	else {
 	    g_string_append (st, "\"}");
 	}
-	
+
 	s = text_to_struct (st->str);
 	break;
 
@@ -229,6 +282,33 @@ bibtex_reverse_field (BibtexField * field,
 
 	g_string_truncate (st, 0);
 
+	/* Create a simple preamble to parse */
+	if (! use_braces) {
+	    for (i = 0 ; i < field->field.author->len; i ++) {
+		author = & g_array_index (field->field.author, BibtexAuthor, i);
+		
+		if (author->last && strchr (author->last, '"')) {
+		    use_braces = TRUE;
+		    break;
+		}
+		if (author->lineage && strchr (author->lineage, '"')) {
+		    use_braces = TRUE;
+		    break;
+		}
+		if (author->first && strchr (author->first, '"')) {
+		    use_braces = TRUE;
+		    break;
+		}
+	    }
+	}
+	
+	if (use_braces) {
+	    g_string_append (st, "@preamble{{");
+	}
+	else {
+	    g_string_append (st, "@preamble{\"");
+	}
+
 	for (i = 0 ; i < field->field.author->len; i ++) {
 	    author = & g_array_index (field->field.author, BibtexAuthor, i);
 
@@ -236,37 +316,71 @@ bibtex_reverse_field (BibtexField * field,
 		g_string_append (st, " and ");
 	    }
 
-	    g_string_append_c (st, '{');
 	    if (author->last) {
+	        /* quotes if there is no first name */
+	        has_space = author_needs_quotes (author->last) ||
+		  (author->first == NULL && 
+		   strpbrk (author->last, " \t") != NULL);
+
+		if (has_space) {
+		    g_string_append_c (st, '{');
+		}
+
 		tmp = recode_string (request, author->last);
 		g_string_append (st, tmp);
 		g_free (tmp);
+
+		if (has_space) {
+		    g_string_append_c (st, '}');
+		}
 	    }
 
 	    if (author->lineage) {
-		g_string_append (st, "}, {");
+		g_string_append (st, ", ");
+
+	        has_space = author_needs_quotes (author->lineage);
+
+		if (has_space) {
+		    g_string_append_c (st, '{');
+		}
+
 		tmp = recode_string (request, author->lineage);
 		g_string_append (st, tmp);
 		g_free (tmp);
+
+		if (has_space) {
+		    g_string_append_c (st, '}');
+		}
 	    }
-	    g_string_append_c (st, '}');
+
 
 	    if (author->first) {
 		g_string_append (st, ", ");
-		g_string_append_c (st, '{');
+
+	        has_space = author_needs_quotes (author->first);
+
+		if (has_space) {
+		    g_string_append_c (st, '{');
+		}
+
 		tmp = recode_string (request, author->first);
 		g_string_append (st, tmp);
 		g_free (tmp);
-		g_string_append_c (st, '}');
+
+		if (has_space) {
+		    g_string_append_c (st, '}');
+		}
 	    }
 	}
 
-	/* Create a simple preamble to parse */
-	g_string_append  (st, "}}");
-	g_string_prepend (st, "@preamble{{");
+	if (use_braces) {
+	    g_string_append (st, "}}");
+	}
+	else {
+	    g_string_append (st, "\"}");
+	}
 
 	s = text_to_struct (st->str);
-
 	break;
 
     case BIBTEX_DATE:
