@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibtexmodule.c,v 1.5.2.1 2000/10/17 13:02:39 fredgo Exp $
+ $Id: bibtexmodule.c,v 1.5.2.2 2001/06/25 14:27:52 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -296,6 +296,11 @@ bib_get_native (PyObject * self, PyObject * args) {
 
     field = field_obj->obj;
 
+    if (field->structure == NULL) {
+      Py_INCREF (Py_None);
+      return Py_None;
+    }
+
     text = bibtex_struct_as_bibtex (field->structure);
     tmp = Py_BuildValue("s", text); 
     g_free (text);
